@@ -645,7 +645,7 @@ import numpy as np
 from matplotlib import colorbar
 
 
-class Water:
+class water:
         #fix
         required_bands = {'mndi','Green','ndwi','Mir2','mbwi'}
         required_indices = {'ndwi','mbwi','mndwi'}
@@ -693,11 +693,11 @@ class Water:
                 except ValueError as e:
                     print(e)
                 bands = {'Red':red,
-                         'Green':green,
-                         'Blue':blue,
-                         'Nir':nir,
-                         'Mir':mir,
-                         'Mir2':mir2}
+                        'Green':green,
+                        'Blue':blue,
+                        'Nir':nir,
+                        'Mir':mir,
+                        'Mir2':mir2}
                 dataset = bands
             # old
             self.input_bands = dataset
@@ -1425,9 +1425,9 @@ class imagedataset(objearth,Water):
             elif command == 'NDMI':
                 val = super().NDMI(eds)
             elif command == 'waterdetect':
-                val = Water(eds).waterdetect()
+                val = water(eds).waterdetect()
             elif command == 'waterquality':
-                val = Water(eds).waterquality()
+                val = water(eds).waterquality()
             else:
                 print('Errro command')
                 break
